import {__decorate} from 'tslib'
import {boundMethod as bind} from 'autobind-decorator'
import {isString} from 'lodash'
import {BaseConfig} from './BaseConfig'
export class Config extends BaseConfig {
  init(app) {
    this.app = app
    this.log = app.logger.instance.scope(this.name)
    return this
  }
  normalizeEntry(c) {
    return isString(c) ? [c, {}] : c
  }
  setPlugin(plugin) {
    this.app.log(`Setting babel plugin: ${plugin}`)
    plugin = this.normalizeEntry(plugin)
    this.plugins = Object.assign(
      Object.assign({}, this.plugins),
      {[plugin[0]]: plugin},
    )
    return this
  }
  setPlugins(plugins) {
    plugins.map(this.setPlugin)
    return this
  }
  setPreset(preset) {
    this.app.log(`Setting babel preset: ${preset}`)
    preset = this.normalizeEntry(preset)
    this.presets = Object.assign(
      Object.assign({}, this.presets),
      {[preset[0]]: preset},
    )
    return this
  }
  setPresets(presets) {
    presets.map(this.setPreset)
    return this
  }
  unsetPreset(preset) {
    !this.presets[preset]
      ? this.log.error(`${preset} not found`, this.presets)
      : delete this.presets[preset]
    return this
  }
  unsetPlugin(plugin) {
    !this.plugins[plugin]
      ? this.log.error(`${plugin} not found`, this.plugins)
      : delete this.plugins[plugin]
    return this
  }
  setPluginOptions(plugin, options) {
    this.plugins[plugin] = [this.plugins[plugin][0], options]
    return this
  }
  setPresetOptions(preset, options) {
    this.presets[preset] = [this.presets[preset][0], options]
    return this
  }
}
__decorate([bind], Config.prototype, 'init', null)
__decorate([bind], Config.prototype, 'normalizeEntry', null)
__decorate([bind], Config.prototype, 'setPlugin', null)
__decorate([bind], Config.prototype, 'setPlugins', null)
__decorate([bind], Config.prototype, 'setPreset', null)
__decorate([bind], Config.prototype, 'setPresets', null)
__decorate([bind], Config.prototype, 'unsetPreset', null)
__decorate([bind], Config.prototype, 'unsetPlugin', null)
__decorate([bind], Config.prototype, 'setPluginOptions', null)
__decorate([bind], Config.prototype, 'setPresetOptions', null)
//# sourceMappingURL=index.js.map
